"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const getLocale_1 = __importDefault(require("./getLocale"));
const validateConfig_1 = __importDefault(require("./validateConfig"));
const server_1 = require("next/server");
function internationalizeRoute(request, config) {
    if (!request) {
        throw new Error(`internationalizeRoute requires a request argument.`);
    }
    if (!config) {
        throw new Error(`internationalizeRoute requires a config argument`);
    }
    const { locales, defaultLocale, localeCookie = 'NEXT_LOCALE', getLocale = getLocale_1.default } = config;
    (0, validateConfig_1.default)(config);
    const pathname = request.nextUrl.pathname;
    const pathLocale = locales.find(locale => pathname.startsWith(`/${locale}/`) || pathname === `/${locale}`);
    if (!pathLocale) {
        let locale = getLocale(request, {
            locales,
            defaultLocale,
            localeCookie
        });
        if (!locales.includes(locale)) {
            console.warn("The getLocale callback must return a locale included in your locales array. Reverting to using defaultLocale.");
            locale = defaultLocale;
        }
        // e.g. incoming request is /products
        // The new URL is now /en-US/products
        return server_1.NextResponse.redirect(new URL(`/${locale}${pathname}`, request.url));
    }
    const response = server_1.NextResponse.next();
    response.headers.set('x-next-i18n-router-locale', pathLocale);
    return response;
}
exports.default = internationalizeRoute;
//# sourceMappingURL=internationalizeRoute.js.map